@@ -68,9 +68,9 @@ def wf_bandstructure2D(structure, c=None):
     '''
     wf = get_wf(structure, "bandstructure.yaml", vis=MPScanRelaxSet2D(structure, force_gamma=True,), \
                 params=[{'vasp_input_set': mpr2d},{},{},{}], common_params={"vasp_cmd": vasp_cmd, "db_file": db_file,}) #"vdw_kernel_dir": vdw_kernel})
-
-    wf = add_common_powerups(wf, c)
     '''
+    wf = add_common_powerups(wf, c)
+
     if c.get("SMALLGAP_KPOINT_MULTIPLY", SMALLGAP_KPOINT_MULTIPLY):
         wf = add_small_gap_multiply(wf, 0.5, 5, "static")
         wf = add_small_gap_multiply(wf, 0.5, 5, "nscf")
@@ -81,7 +81,8 @@ def wf_bandstructure2D(structure, c=None):
     if c.get("ADD_WF_METADATA", ADD_WF_METADATA):
         wf = add_wf_metadata(wf, structure)
 
-    print(wf)
+    wf.name = "{}:{}".format(structure.composition.reduced_formula, "bandStructure")
+
     '''
     fws = wf.fws
     fws[0] = new_firework
